import { EventEmitter } from "../../stencil-public-runtime";
import { MapGeoJSONFeature } from "maplibre-gl";
export declare class StoryStep {
  el: HTMLGlStoryStepElement;
  /**
   * An event emitter that, when fired, emulates a user clicking on the map
   */
  glFeatureClick: EventEmitter<{
    features: MapGeoJSONFeature[];
  }>;
  /**
   * Whether this step in the story is active
   */
  readonly active: boolean;
  /**
   * Whether this is the first step in the story
   */
  readonly first: boolean;
  /**
   * Whether this is the last step in the story
   */
  readonly last: boolean;
  /**
   * The 'hash' that represents the location of the story
   * Visible in the browser url when the 'hash' property of {@link ../map} is set to true.
   */
  readonly hash: string;
  /**
   * Whether or not to try to locate the click feature before the map moves
   */
  readonly clickBeforeHash: boolean;
  /**
   * Whether or not to click after the map has moved
   */
  readonly clickAfterIdle: boolean;
  /**
   * Number of milliseconds to wait before clicking the map
   */
  readonly clickDelay: number;
  /**
   * What layer the click should be fired on
   */
  readonly clickLayer: string;
  /**
   * The attribute name of the feature you are clicking on
   * In essence you will be clicking on the features whose [clickProperty] = clickValue
   */
  readonly clickProperty: string;
  /**
   * The value the feature will have in the clickProperty attribute.
   * In essence you will be clicking on the features whose [clickProperty] = clickValue
   *
   * Alternatively if clickProperty is not set, clickValue refers to the featureID of what you are clicking on.
   */
  readonly clickValue: number;
  /**
   * The ID of the map this story step works with
   */
  readonly mapId: string;
  private _didClick;
  activeChanged(): void;
  private activate;
  private scheduleClick;
  private fireClickEvent;
  render(): any;
}
